# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetGitopsAgentOperatorYamlResult',
    'AwaitableGetGitopsAgentOperatorYamlResult',
    'get_gitops_agent_operator_yaml',
    'get_gitops_agent_operator_yaml_output',
]

@pulumi.output_type
class GetGitopsAgentOperatorYamlResult:
    """
    A collection of values returned by getGitopsAgentOperatorYaml.
    """
    def __init__(__self__, ca_data=None, id=None, identifier=None, namespace=None, org_id=None, private_key=None, project_id=None, proxies=None, skip_crds=None, yaml=None):
        if ca_data and not isinstance(ca_data, str):
            raise TypeError("Expected argument 'ca_data' to be a str")
        pulumi.set(__self__, "ca_data", ca_data)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if private_key and not isinstance(private_key, str):
            raise TypeError("Expected argument 'private_key' to be a str")
        pulumi.set(__self__, "private_key", private_key)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if proxies and not isinstance(proxies, list):
            raise TypeError("Expected argument 'proxies' to be a list")
        pulumi.set(__self__, "proxies", proxies)
        if skip_crds and not isinstance(skip_crds, bool):
            raise TypeError("Expected argument 'skip_crds' to be a bool")
        pulumi.set(__self__, "skip_crds", skip_crds)
        if yaml and not isinstance(yaml, str):
            raise TypeError("Expected argument 'yaml' to be a str")
        pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter(name="caData")
    def ca_data(self) -> Optional[_builtins.str]:
        """
        CA data of the GitOps agent, base64 encoded content of ca chain.
        """
        return pulumi.get(self, "ca_data")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the GitOps agent.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> _builtins.str:
        """
        The kubernetes namespace where the agent is installed.
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Organization identifier of the GitOps agent.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[_builtins.str]:
        """
        Private key for the GitOps agent. If provided authentication token will not be regenerated. Must be base64 encoded.
        """
        return pulumi.get(self, "private_key")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Project identifier of the GitOps agent.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def proxies(self) -> Optional[Sequence['outputs.GetGitopsAgentOperatorYamlProxyResult']]:
        """
        Proxy settings for the GitOps agent.
        """
        return pulumi.get(self, "proxies")

    @_builtins.property
    @pulumi.getter(name="skipCrds")
    def skip_crds(self) -> Optional[_builtins.bool]:
        """
        Skip CRDs for the GitOps agent.
        """
        return pulumi.get(self, "skip_crds")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> _builtins.str:
        """
        The operator manifest YAML of the GitOps agent.
        """
        return pulumi.get(self, "yaml")


class AwaitableGetGitopsAgentOperatorYamlResult(GetGitopsAgentOperatorYamlResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGitopsAgentOperatorYamlResult(
            ca_data=self.ca_data,
            id=self.id,
            identifier=self.identifier,
            namespace=self.namespace,
            org_id=self.org_id,
            private_key=self.private_key,
            project_id=self.project_id,
            proxies=self.proxies,
            skip_crds=self.skip_crds,
            yaml=self.yaml)


def get_gitops_agent_operator_yaml(ca_data: Optional[_builtins.str] = None,
                                   identifier: Optional[_builtins.str] = None,
                                   namespace: Optional[_builtins.str] = None,
                                   org_id: Optional[_builtins.str] = None,
                                   private_key: Optional[_builtins.str] = None,
                                   project_id: Optional[_builtins.str] = None,
                                   proxies: Optional[Sequence[Union['GetGitopsAgentOperatorYamlProxyArgs', 'GetGitopsAgentOperatorYamlProxyArgsDict']]] = None,
                                   skip_crds: Optional[_builtins.bool] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGitopsAgentOperatorYamlResult:
    """
    Datasource for fetching a Harness Gitops Agent operator manifest YAML.

    ## Example Usage


    :param _builtins.str ca_data: CA data of the GitOps agent, base64 encoded content of ca chain.
    :param _builtins.str identifier: Identifier of the GitOps agent.
    :param _builtins.str namespace: The kubernetes namespace where the agent is installed.
    :param _builtins.str org_id: Organization identifier of the GitOps agent.
    :param _builtins.str private_key: Private key for the GitOps agent. If provided authentication token will not be regenerated. Must be base64 encoded.
    :param _builtins.str project_id: Project identifier of the GitOps agent.
    :param Sequence[Union['GetGitopsAgentOperatorYamlProxyArgs', 'GetGitopsAgentOperatorYamlProxyArgsDict']] proxies: Proxy settings for the GitOps agent.
    :param _builtins.bool skip_crds: Skip CRDs for the GitOps agent.
    """
    __args__ = dict()
    __args__['caData'] = ca_data
    __args__['identifier'] = identifier
    __args__['namespace'] = namespace
    __args__['orgId'] = org_id
    __args__['privateKey'] = private_key
    __args__['projectId'] = project_id
    __args__['proxies'] = proxies
    __args__['skipCrds'] = skip_crds
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getGitopsAgentOperatorYaml:getGitopsAgentOperatorYaml', __args__, opts=opts, typ=GetGitopsAgentOperatorYamlResult).value

    return AwaitableGetGitopsAgentOperatorYamlResult(
        ca_data=pulumi.get(__ret__, 'ca_data'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        namespace=pulumi.get(__ret__, 'namespace'),
        org_id=pulumi.get(__ret__, 'org_id'),
        private_key=pulumi.get(__ret__, 'private_key'),
        project_id=pulumi.get(__ret__, 'project_id'),
        proxies=pulumi.get(__ret__, 'proxies'),
        skip_crds=pulumi.get(__ret__, 'skip_crds'),
        yaml=pulumi.get(__ret__, 'yaml'))
def get_gitops_agent_operator_yaml_output(ca_data: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                          identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                          namespace: Optional[pulumi.Input[_builtins.str]] = None,
                                          org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                          private_key: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                          project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                          proxies: Optional[pulumi.Input[Optional[Sequence[Union['GetGitopsAgentOperatorYamlProxyArgs', 'GetGitopsAgentOperatorYamlProxyArgsDict']]]]] = None,
                                          skip_crds: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGitopsAgentOperatorYamlResult]:
    """
    Datasource for fetching a Harness Gitops Agent operator manifest YAML.

    ## Example Usage


    :param _builtins.str ca_data: CA data of the GitOps agent, base64 encoded content of ca chain.
    :param _builtins.str identifier: Identifier of the GitOps agent.
    :param _builtins.str namespace: The kubernetes namespace where the agent is installed.
    :param _builtins.str org_id: Organization identifier of the GitOps agent.
    :param _builtins.str private_key: Private key for the GitOps agent. If provided authentication token will not be regenerated. Must be base64 encoded.
    :param _builtins.str project_id: Project identifier of the GitOps agent.
    :param Sequence[Union['GetGitopsAgentOperatorYamlProxyArgs', 'GetGitopsAgentOperatorYamlProxyArgsDict']] proxies: Proxy settings for the GitOps agent.
    :param _builtins.bool skip_crds: Skip CRDs for the GitOps agent.
    """
    __args__ = dict()
    __args__['caData'] = ca_data
    __args__['identifier'] = identifier
    __args__['namespace'] = namespace
    __args__['orgId'] = org_id
    __args__['privateKey'] = private_key
    __args__['projectId'] = project_id
    __args__['proxies'] = proxies
    __args__['skipCrds'] = skip_crds
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getGitopsAgentOperatorYaml:getGitopsAgentOperatorYaml', __args__, opts=opts, typ=GetGitopsAgentOperatorYamlResult)
    return __ret__.apply(lambda __response__: GetGitopsAgentOperatorYamlResult(
        ca_data=pulumi.get(__response__, 'ca_data'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        namespace=pulumi.get(__response__, 'namespace'),
        org_id=pulumi.get(__response__, 'org_id'),
        private_key=pulumi.get(__response__, 'private_key'),
        project_id=pulumi.get(__response__, 'project_id'),
        proxies=pulumi.get(__response__, 'proxies'),
        skip_crds=pulumi.get(__response__, 'skip_crds'),
        yaml=pulumi.get(__response__, 'yaml')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetWorkspaceOutputValueResult',
    'AwaitableGetWorkspaceOutputValueResult',
    'get_workspace_output_value',
    'get_workspace_output_value_output',
]

@pulumi.output_type
class GetWorkspaceOutputValueResult:
    """
    A collection of values returned by getWorkspaceOutputValue.
    """
    def __init__(__self__, id=None, identifier=None, org_id=None, output_values=None, project_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if output_values and not isinstance(output_values, list):
            raise TypeError("Expected argument 'output_values' to be a list")
        pulumi.set(__self__, "output_values", output_values)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the Workspace.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        Organization identifier of the organization the workspace resides in.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="outputValues")
    def output_values(self) -> Sequence['outputs.GetWorkspaceOutputValueOutputValueResult']:
        return pulumi.get(self, "output_values")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        Project identifier of the project the workspace resides in.
        """
        return pulumi.get(self, "project_id")


class AwaitableGetWorkspaceOutputValueResult(GetWorkspaceOutputValueResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetWorkspaceOutputValueResult(
            id=self.id,
            identifier=self.identifier,
            org_id=self.org_id,
            output_values=self.output_values,
            project_id=self.project_id)


def get_workspace_output_value(identifier: Optional[_builtins.str] = None,
                               org_id: Optional[_builtins.str] = None,
                               project_id: Optional[_builtins.str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetWorkspaceOutputValueResult:
    """
    Data source for retrieving workspace outputs.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_workspace_output_value(identifier="identifier",
        org_id="org_id",
        project_id="project_id")
    ```


    :param _builtins.str identifier: Identifier of the Workspace.
    :param _builtins.str org_id: Organization identifier of the organization the workspace resides in.
    :param _builtins.str project_id: Project identifier of the project the workspace resides in.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getWorkspaceOutputValue:getWorkspaceOutputValue', __args__, opts=opts, typ=GetWorkspaceOutputValueResult).value

    return AwaitableGetWorkspaceOutputValueResult(
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        org_id=pulumi.get(__ret__, 'org_id'),
        output_values=pulumi.get(__ret__, 'output_values'),
        project_id=pulumi.get(__ret__, 'project_id'))
def get_workspace_output_value_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                      org_id: Optional[pulumi.Input[_builtins.str]] = None,
                                      project_id: Optional[pulumi.Input[_builtins.str]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetWorkspaceOutputValueResult]:
    """
    Data source for retrieving workspace outputs.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_workspace_output_value(identifier="identifier",
        org_id="org_id",
        project_id="project_id")
    ```


    :param _builtins.str identifier: Identifier of the Workspace.
    :param _builtins.str org_id: Organization identifier of the organization the workspace resides in.
    :param _builtins.str project_id: Project identifier of the project the workspace resides in.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getWorkspaceOutputValue:getWorkspaceOutputValue', __args__, opts=opts, typ=GetWorkspaceOutputValueResult)
    return __ret__.apply(lambda __response__: GetWorkspaceOutputValueResult(
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        org_id=pulumi.get(__response__, 'org_id'),
        output_values=pulumi.get(__response__, 'output_values'),
        project_id=pulumi.get(__response__, 'project_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetPolicySetResult',
    'AwaitableGetPolicySetResult',
    'get_policy_set',
    'get_policy_set_output',
]

@pulumi.output_type
class GetPolicySetResult:
    """
    A collection of values returned by getPolicySet.
    """
    def __init__(__self__, action=None, description=None, enabled=None, id=None, identifier=None, name=None, org_id=None, policies=None, policy_references=None, project_id=None, tags=None, type=None):
        if action and not isinstance(action, str):
            raise TypeError("Expected argument 'action' to be a str")
        pulumi.set(__self__, "action", action)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)
        if policy_references and not isinstance(policy_references, list):
            raise TypeError("Expected argument 'policy_references' to be a list")
        pulumi.set(__self__, "policy_references", policy_references)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def action(self) -> _builtins.str:
        """
        Action code for the policyset.
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[_builtins.bool]:
        """
        Enabled for the policyset.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Use 'policy_references' instead. This field will be removed in a future version.""")
    def policies(self) -> Sequence['outputs.GetPolicySetPolicyResult']:
        """
        List of policy identifiers / severity for the policyset. Deprecated: Use 'policy_references' instead.
        """
        return pulumi.get(self, "policies")

    @_builtins.property
    @pulumi.getter(name="policyReferences")
    def policy_references(self) -> Sequence['outputs.GetPolicySetPolicyReferenceResult']:
        """
        Set of policy identifiers / severity for the policyset. Order is not significant.
        """
        return pulumi.get(self, "policy_references")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Type of the policyset.
        """
        return pulumi.get(self, "type")


class AwaitableGetPolicySetResult(GetPolicySetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPolicySetResult(
            action=self.action,
            description=self.description,
            enabled=self.enabled,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            org_id=self.org_id,
            policies=self.policies,
            policy_references=self.policy_references,
            project_id=self.project_id,
            tags=self.tags,
            type=self.type)


def get_policy_set(action: Optional[_builtins.str] = None,
                   enabled: Optional[_builtins.bool] = None,
                   identifier: Optional[_builtins.str] = None,
                   name: Optional[_builtins.str] = None,
                   org_id: Optional[_builtins.str] = None,
                   policies: Optional[Sequence[Union['GetPolicySetPolicyArgs', 'GetPolicySetPolicyArgsDict']]] = None,
                   policy_references: Optional[Sequence[Union['GetPolicySetPolicyReferenceArgs', 'GetPolicySetPolicyReferenceArgsDict']]] = None,
                   project_id: Optional[_builtins.str] = None,
                   type: Optional[_builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPolicySetResult:
    """
    Data source for retrieving a Harness policyset.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_policy_set(identifier="harness_platform_policyset.test.identifier",
        name="harness_platform_policyset.test.name",
        action="onrun",
        type="pipeline",
        enabled=True,
        policy_references=[{
            "identifier": "always_run",
            "severity": "warning",
        }])
    ```


    :param _builtins.str action: Action code for the policyset.
    :param _builtins.bool enabled: Enabled for the policyset.
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param Sequence[Union['GetPolicySetPolicyArgs', 'GetPolicySetPolicyArgsDict']] policies: List of policy identifiers / severity for the policyset. Deprecated: Use 'policy_references' instead.
    :param Sequence[Union['GetPolicySetPolicyReferenceArgs', 'GetPolicySetPolicyReferenceArgsDict']] policy_references: Set of policy identifiers / severity for the policyset. Order is not significant.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str type: Type of the policyset.
    """
    __args__ = dict()
    __args__['action'] = action
    __args__['enabled'] = enabled
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['policies'] = policies
    __args__['policyReferences'] = policy_references
    __args__['projectId'] = project_id
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getPolicySet:getPolicySet', __args__, opts=opts, typ=GetPolicySetResult).value

    return AwaitableGetPolicySetResult(
        action=pulumi.get(__ret__, 'action'),
        description=pulumi.get(__ret__, 'description'),
        enabled=pulumi.get(__ret__, 'enabled'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        policies=pulumi.get(__ret__, 'policies'),
        policy_references=pulumi.get(__ret__, 'policy_references'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'),
        type=pulumi.get(__ret__, 'type'))
def get_policy_set_output(action: Optional[pulumi.Input[_builtins.str]] = None,
                          enabled: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                          identifier: Optional[pulumi.Input[_builtins.str]] = None,
                          name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          policies: Optional[pulumi.Input[Optional[Sequence[Union['GetPolicySetPolicyArgs', 'GetPolicySetPolicyArgsDict']]]]] = None,
                          policy_references: Optional[pulumi.Input[Optional[Sequence[Union['GetPolicySetPolicyReferenceArgs', 'GetPolicySetPolicyReferenceArgsDict']]]]] = None,
                          project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          type: Optional[pulumi.Input[_builtins.str]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPolicySetResult]:
    """
    Data source for retrieving a Harness policyset.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_policy_set(identifier="harness_platform_policyset.test.identifier",
        name="harness_platform_policyset.test.name",
        action="onrun",
        type="pipeline",
        enabled=True,
        policy_references=[{
            "identifier": "always_run",
            "severity": "warning",
        }])
    ```


    :param _builtins.str action: Action code for the policyset.
    :param _builtins.bool enabled: Enabled for the policyset.
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param Sequence[Union['GetPolicySetPolicyArgs', 'GetPolicySetPolicyArgsDict']] policies: List of policy identifiers / severity for the policyset. Deprecated: Use 'policy_references' instead.
    :param Sequence[Union['GetPolicySetPolicyReferenceArgs', 'GetPolicySetPolicyReferenceArgsDict']] policy_references: Set of policy identifiers / severity for the policyset. Order is not significant.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str type: Type of the policyset.
    """
    __args__ = dict()
    __args__['action'] = action
    __args__['enabled'] = enabled
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['policies'] = policies
    __args__['policyReferences'] = policy_references
    __args__['projectId'] = project_id
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getPolicySet:getPolicySet', __args__, opts=opts, typ=GetPolicySetResult)
    return __ret__.apply(lambda __response__: GetPolicySetResult(
        action=pulumi.get(__response__, 'action'),
        description=pulumi.get(__response__, 'description'),
        enabled=pulumi.get(__response__, 'enabled'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        policies=pulumi.get(__response__, 'policies'),
        policy_references=pulumi.get(__response__, 'policy_references'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SecretFileArgs', 'SecretFile']

@pulumi.input_type
class SecretFileArgs:
    def __init__(__self__, *,
                 file_path: pulumi.Input[_builtins.str],
                 identifier: pulumi.Input[_builtins.str],
                 secret_manager_identifier: pulumi.Input[_builtins.str],
                 additional_metadatas: Optional[pulumi.Input[Sequence[pulumi.Input['SecretFileAdditionalMetadataArgs']]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a SecretFile resource.
        :param pulumi.Input[_builtins.str] file_path: Path of the file containing secret value
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] secret_manager_identifier: Identifier of the Secret Manager used to manage the secret.
        :param pulumi.Input[Sequence[pulumi.Input['SecretFileAdditionalMetadataArgs']]] additional_metadatas: Additional Metadata for the Secret
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        pulumi.set(__self__, "file_path", file_path)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "secret_manager_identifier", secret_manager_identifier)
        if additional_metadatas is not None:
            pulumi.set(__self__, "additional_metadatas", additional_metadatas)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="filePath")
    def file_path(self) -> pulumi.Input[_builtins.str]:
        """
        Path of the file containing secret value
        """
        return pulumi.get(self, "file_path")

    @file_path.setter
    def file_path(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "file_path", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="secretManagerIdentifier")
    def secret_manager_identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the Secret Manager used to manage the secret.
        """
        return pulumi.get(self, "secret_manager_identifier")

    @secret_manager_identifier.setter
    def secret_manager_identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "secret_manager_identifier", value)

    @_builtins.property
    @pulumi.getter(name="additionalMetadatas")
    def additional_metadatas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecretFileAdditionalMetadataArgs']]]]:
        """
        Additional Metadata for the Secret
        """
        return pulumi.get(self, "additional_metadatas")

    @additional_metadatas.setter
    def additional_metadatas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecretFileAdditionalMetadataArgs']]]]):
        pulumi.set(self, "additional_metadatas", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _SecretFileState:
    def __init__(__self__, *,
                 additional_metadatas: Optional[pulumi.Input[Sequence[pulumi.Input['SecretFileAdditionalMetadataArgs']]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 file_path: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_manager_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering SecretFile resources.
        :param pulumi.Input[Sequence[pulumi.Input['SecretFileAdditionalMetadataArgs']]] additional_metadatas: Additional Metadata for the Secret
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] file_path: Path of the file containing secret value
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] secret_manager_identifier: Identifier of the Secret Manager used to manage the secret.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        if additional_metadatas is not None:
            pulumi.set(__self__, "additional_metadatas", additional_metadatas)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if file_path is not None:
            pulumi.set(__self__, "file_path", file_path)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if secret_manager_identifier is not None:
            pulumi.set(__self__, "secret_manager_identifier", secret_manager_identifier)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="additionalMetadatas")
    def additional_metadatas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecretFileAdditionalMetadataArgs']]]]:
        """
        Additional Metadata for the Secret
        """
        return pulumi.get(self, "additional_metadatas")

    @additional_metadatas.setter
    def additional_metadatas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecretFileAdditionalMetadataArgs']]]]):
        pulumi.set(self, "additional_metadatas", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="filePath")
    def file_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path of the file containing secret value
        """
        return pulumi.get(self, "file_path")

    @file_path.setter
    def file_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "file_path", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="secretManagerIdentifier")
    def secret_manager_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the Secret Manager used to manage the secret.
        """
        return pulumi.get(self, "secret_manager_identifier")

    @secret_manager_identifier.setter
    def secret_manager_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_manager_identifier", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("harness:platform/secretFile:SecretFile")
class SecretFile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_metadatas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecretFileAdditionalMetadataArgs', 'SecretFileAdditionalMetadataArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 file_path: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_manager_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating a secret of type secret file in Harness.

        > [!NOTE]
        > 1. Selecting a Customer managed Key (CMK) for encryption is supported in Harness Delegate version 25.11.87300 or later and is behind the feature flag `PL_ENABLE_NON_DEFAULT_ENCRYPTION_KEY`. Contact Harness Support to enable the feature.
        > 2. This option would be unavailable if the AWS Secret Manager connector has the option Use "put-secret-value" action to update secret value enabled.

        Refer to the [documentation](https://developer.harness.io/docs/platform/secrets/secrets-management/add-an-aws-secret-manager/#create-a-text-or-file-secret) for details.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.SecretFile("example",
            identifier="identifier",
            name="name",
            description="test",
            tags=["foo:bar"],
            file_path="file_path",
            secret_manager_identifier="harnessSecretManager")
        # With AWS Secret Manager KMS Key
        aws_secret_manager = harness.platform.SecretFile("aws_secret_manager",
            identifier="identifier",
            name="name",
            description="example",
            tags=["foo:bar"],
            file_path="file_path",
            secret_manager_identifier="awsSecretManager",
            additional_metadatas=[{
                "values": [{
                    "kms_key_id": "kmsKeyId",
                }],
            }])
        # With GCP Secret Manager project ID and region
        gcp_secret_manager = harness.platform.SecretFile("gcp_secret_manager",
            identifier="identifier",
            name="name",
            description="example",
            tags=["foo:bar"],
            file_path="file_path",
            secret_manager_identifier="gcpSecretManager",
            additional_metadatas=[{
                "values": [{
                    "regions": "us-east1",
                    "gcp_project_id": "my-gcp-project-id",
                }],
            }])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level secret file

        ```sh
        $ pulumi import harness:platform/secretFile:SecretFile example <secret_file_id>
        ```

        Import org level secret file

        ```sh
        $ pulumi import harness:platform/secretFile:SecretFile example <ord_id>/<secret_file_id>
        ```

        Import project level secret file

        ```sh
        $ pulumi import harness:platform/secretFile:SecretFile example <org_id>/<project_id>/<secret_file_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SecretFileAdditionalMetadataArgs', 'SecretFileAdditionalMetadataArgsDict']]]] additional_metadatas: Additional Metadata for the Secret
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] file_path: Path of the file containing secret value
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] secret_manager_identifier: Identifier of the Secret Manager used to manage the secret.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecretFileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a secret of type secret file in Harness.

        > [!NOTE]
        > 1. Selecting a Customer managed Key (CMK) for encryption is supported in Harness Delegate version 25.11.87300 or later and is behind the feature flag `PL_ENABLE_NON_DEFAULT_ENCRYPTION_KEY`. Contact Harness Support to enable the feature.
        > 2. This option would be unavailable if the AWS Secret Manager connector has the option Use "put-secret-value" action to update secret value enabled.

        Refer to the [documentation](https://developer.harness.io/docs/platform/secrets/secrets-management/add-an-aws-secret-manager/#create-a-text-or-file-secret) for details.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.SecretFile("example",
            identifier="identifier",
            name="name",
            description="test",
            tags=["foo:bar"],
            file_path="file_path",
            secret_manager_identifier="harnessSecretManager")
        # With AWS Secret Manager KMS Key
        aws_secret_manager = harness.platform.SecretFile("aws_secret_manager",
            identifier="identifier",
            name="name",
            description="example",
            tags=["foo:bar"],
            file_path="file_path",
            secret_manager_identifier="awsSecretManager",
            additional_metadatas=[{
                "values": [{
                    "kms_key_id": "kmsKeyId",
                }],
            }])
        # With GCP Secret Manager project ID and region
        gcp_secret_manager = harness.platform.SecretFile("gcp_secret_manager",
            identifier="identifier",
            name="name",
            description="example",
            tags=["foo:bar"],
            file_path="file_path",
            secret_manager_identifier="gcpSecretManager",
            additional_metadatas=[{
                "values": [{
                    "regions": "us-east1",
                    "gcp_project_id": "my-gcp-project-id",
                }],
            }])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level secret file

        ```sh
        $ pulumi import harness:platform/secretFile:SecretFile example <secret_file_id>
        ```

        Import org level secret file

        ```sh
        $ pulumi import harness:platform/secretFile:SecretFile example <ord_id>/<secret_file_id>
        ```

        Import project level secret file

        ```sh
        $ pulumi import harness:platform/secretFile:SecretFile example <org_id>/<project_id>/<secret_file_id>
        ```

        :param str resource_name: The name of the resource.
        :param SecretFileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecretFileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_metadatas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecretFileAdditionalMetadataArgs', 'SecretFileAdditionalMetadataArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 file_path: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_manager_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecretFileArgs.__new__(SecretFileArgs)

            __props__.__dict__["additional_metadatas"] = additional_metadatas
            __props__.__dict__["description"] = description
            if file_path is None and not opts.urn:
                raise TypeError("Missing required property 'file_path'")
            __props__.__dict__["file_path"] = file_path
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            if secret_manager_identifier is None and not opts.urn:
                raise TypeError("Missing required property 'secret_manager_identifier'")
            __props__.__dict__["secret_manager_identifier"] = secret_manager_identifier
            __props__.__dict__["tags"] = tags
        super(SecretFile, __self__).__init__(
            'harness:platform/secretFile:SecretFile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_metadatas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecretFileAdditionalMetadataArgs', 'SecretFileAdditionalMetadataArgsDict']]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            file_path: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            secret_manager_identifier: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'SecretFile':
        """
        Get an existing SecretFile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SecretFileAdditionalMetadataArgs', 'SecretFileAdditionalMetadataArgsDict']]]] additional_metadatas: Additional Metadata for the Secret
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] file_path: Path of the file containing secret value
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] secret_manager_identifier: Identifier of the Secret Manager used to manage the secret.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecretFileState.__new__(_SecretFileState)

        __props__.__dict__["additional_metadatas"] = additional_metadatas
        __props__.__dict__["description"] = description
        __props__.__dict__["file_path"] = file_path
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["secret_manager_identifier"] = secret_manager_identifier
        __props__.__dict__["tags"] = tags
        return SecretFile(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="additionalMetadatas")
    def additional_metadatas(self) -> pulumi.Output[Optional[Sequence['outputs.SecretFileAdditionalMetadata']]]:
        """
        Additional Metadata for the Secret
        """
        return pulumi.get(self, "additional_metadatas")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="filePath")
    def file_path(self) -> pulumi.Output[_builtins.str]:
        """
        Path of the file containing secret value
        """
        return pulumi.get(self, "file_path")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="secretManagerIdentifier")
    def secret_manager_identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the Secret Manager used to manage the secret.
        """
        return pulumi.get(self, "secret_manager_identifier")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'OrchestratorConfigBinpackingArgs',
    'OrchestratorConfigBinpackingArgsDict',
    'OrchestratorConfigBinpackingDisruptionArgs',
    'OrchestratorConfigBinpackingDisruptionArgsDict',
    'OrchestratorConfigBinpackingDisruptionBudgetArgs',
    'OrchestratorConfigBinpackingDisruptionBudgetArgsDict',
    'OrchestratorConfigBinpackingDisruptionBudgetScheduleArgs',
    'OrchestratorConfigBinpackingDisruptionBudgetScheduleArgsDict',
    'OrchestratorConfigBinpackingPodEvictionArgs',
    'OrchestratorConfigBinpackingPodEvictionArgsDict',
    'OrchestratorConfigBinpackingPodEvictionThresholdArgs',
    'OrchestratorConfigBinpackingPodEvictionThresholdArgsDict',
    'OrchestratorConfigCommitmentIntegrationArgs',
    'OrchestratorConfigCommitmentIntegrationArgsDict',
    'OrchestratorConfigDistributionArgs',
    'OrchestratorConfigDistributionArgsDict',
    'OrchestratorConfigNodePreferencesArgs',
    'OrchestratorConfigNodePreferencesArgsDict',
    'OrchestratorConfigReplacementScheduleArgs',
    'OrchestratorConfigReplacementScheduleArgsDict',
    'OrchestratorConfigReplacementScheduleAppliesToArgs',
    'OrchestratorConfigReplacementScheduleAppliesToArgsDict',
    'OrchestratorConfigReplacementScheduleWindowDetailsArgs',
    'OrchestratorConfigReplacementScheduleWindowDetailsArgsDict',
    'GetOrchestratorConfigBinpackingArgs',
    'GetOrchestratorConfigBinpackingArgsDict',
    'GetOrchestratorConfigBinpackingDisruptionArgs',
    'GetOrchestratorConfigBinpackingDisruptionArgsDict',
    'GetOrchestratorConfigBinpackingDisruptionBudgetArgs',
    'GetOrchestratorConfigBinpackingDisruptionBudgetArgsDict',
    'GetOrchestratorConfigBinpackingDisruptionBudgetScheduleArgs',
    'GetOrchestratorConfigBinpackingDisruptionBudgetScheduleArgsDict',
    'GetOrchestratorConfigBinpackingPodEvictionArgs',
    'GetOrchestratorConfigBinpackingPodEvictionArgsDict',
    'GetOrchestratorConfigBinpackingPodEvictionThresholdArgs',
    'GetOrchestratorConfigBinpackingPodEvictionThresholdArgsDict',
    'GetOrchestratorConfigCommitmentIntegrationArgs',
    'GetOrchestratorConfigCommitmentIntegrationArgsDict',
    'GetOrchestratorConfigDistributionArgs',
    'GetOrchestratorConfigDistributionArgsDict',
    'GetOrchestratorConfigNodePreferencesArgs',
    'GetOrchestratorConfigNodePreferencesArgsDict',
    'GetOrchestratorConfigReplacementScheduleArgs',
    'GetOrchestratorConfigReplacementScheduleArgsDict',
    'GetOrchestratorConfigReplacementScheduleAppliesToArgs',
    'GetOrchestratorConfigReplacementScheduleAppliesToArgsDict',
    'GetOrchestratorConfigReplacementScheduleWindowDetailsArgs',
    'GetOrchestratorConfigReplacementScheduleWindowDetailsArgsDict',
]

MYPY = False

if not MYPY:
    class OrchestratorConfigBinpackingArgsDict(TypedDict):
        disruption: NotRequired[pulumi.Input['OrchestratorConfigBinpackingDisruptionArgsDict']]
        """
        Harness disruption configuration
        """
        pod_eviction: NotRequired[pulumi.Input['OrchestratorConfigBinpackingPodEvictionArgsDict']]
        """
        Harness Pod Evictor Configuration
        """
elif False:
    OrchestratorConfigBinpackingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OrchestratorConfigBinpackingArgs:
    def __init__(__self__, *,
                 disruption: Optional[pulumi.Input['OrchestratorConfigBinpackingDisruptionArgs']] = None,
                 pod_eviction: Optional[pulumi.Input['OrchestratorConfigBinpackingPodEvictionArgs']] = None):
        """
        :param pulumi.Input['OrchestratorConfigBinpackingDisruptionArgs'] disruption: Harness disruption configuration
        :param pulumi.Input['OrchestratorConfigBinpackingPodEvictionArgs'] pod_eviction: Harness Pod Evictor Configuration
        """
        if disruption is not None:
            pulumi.set(__self__, "disruption", disruption)
        if pod_eviction is not None:
            pulumi.set(__self__, "pod_eviction", pod_eviction)

    @_builtins.property
    @pulumi.getter
    def disruption(self) -> Optional[pulumi.Input['OrchestratorConfigBinpackingDisruptionArgs']]:
        """
        Harness disruption configuration
        """
        return pulumi.get(self, "disruption")

    @disruption.setter
    def disruption(self, value: Optional[pulumi.Input['OrchestratorConfigBinpackingDisruptionArgs']]):
        pulumi.set(self, "disruption", value)

    @_builtins.property
    @pulumi.getter(name="podEviction")
    def pod_eviction(self) -> Optional[pulumi.Input['OrchestratorConfigBinpackingPodEvictionArgs']]:
        """
        Harness Pod Evictor Configuration
        """
        return pulumi.get(self, "pod_eviction")

    @pod_eviction.setter
    def pod_eviction(self, value: Optional[pulumi.Input['OrchestratorConfigBinpackingPodEvictionArgs']]):
        pulumi.set(self, "pod_eviction", value)


if not MYPY:
    class OrchestratorConfigBinpackingDisruptionArgsDict(TypedDict):
        budgets: NotRequired[pulumi.Input[Sequence[pulumi.Input['OrchestratorConfigBinpackingDisruptionBudgetArgsDict']]]]
        """
        Budgets for disruption
        """
        criteria: NotRequired[pulumi.Input[_builtins.str]]
        """
        Criteria for considering a nodes for disruption
        """
        delay: NotRequired[pulumi.Input[_builtins.str]]
        """
        Deletion delay
        """
elif False:
    OrchestratorConfigBinpackingDisruptionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OrchestratorConfigBinpackingDisruptionArgs:
    def __init__(__self__, *,
                 budgets: Optional[pulumi.Input[Sequence[pulumi.Input['OrchestratorConfigBinpackingDisruptionBudgetArgs']]]] = None,
                 criteria: Optional[pulumi.Input[_builtins.str]] = None,
                 delay: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input['OrchestratorConfigBinpackingDisruptionBudgetArgs']]] budgets: Budgets for disruption
        :param pulumi.Input[_builtins.str] criteria: Criteria for considering a nodes for disruption
        :param pulumi.Input[_builtins.str] delay: Deletion delay
        """
        if budgets is not None:
            pulumi.set(__self__, "budgets", budgets)
        if criteria is not None:
            pulumi.set(__self__, "criteria", criteria)
        if delay is not None:
            pulumi.set(__self__, "delay", delay)

    @_builtins.property
    @pulumi.getter
    def budgets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['OrchestratorConfigBinpackingDisruptionBudgetArgs']]]]:
        """
        Budgets for disruption
        """
        return pulumi.get(self, "budgets")

    @budgets.setter
    def budgets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['OrchestratorConfigBinpackingDisruptionBudgetArgs']]]]):
        pulumi.set(self, "budgets", value)

    @_builtins.property
    @pulumi.getter
    def criteria(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Criteria for considering a nodes for disruption
        """
        return pulumi.get(self, "criteria")

    @criteria.setter
    def criteria(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "criteria", value)

    @_builtins.property
    @pulumi.getter
    def delay(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Deletion delay
        """
        return pulumi.get(self, "delay")

    @delay.setter
    def delay(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "delay", value)


if not MYPY:
    class OrchestratorConfigBinpackingDisruptionBudgetArgsDict(TypedDict):
        nodes: pulumi.Input[_builtins.str]
        """
        Number or percentage of Nodes to consider for disruption
        """
        reasons: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        Reasons for disruption
        """
        schedule: NotRequired[pulumi.Input['OrchestratorConfigBinpackingDisruptionBudgetScheduleArgsDict']]
        """
        Schedule for disruption budget
        """
elif False:
    OrchestratorConfigBinpackingDisruptionBudgetArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OrchestratorConfigBinpackingDisruptionBudgetArgs:
    def __init__(__self__, *,
                 nodes: pulumi.Input[_builtins.str],
                 reasons: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 schedule: Optional[pulumi.Input['OrchestratorConfigBinpackingDisruptionBudgetScheduleArgs']] = None):
        """
        :param pulumi.Input[_builtins.str] nodes: Number or percentage of Nodes to consider for disruption
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] reasons: Reasons for disruption
        :param pulumi.Input['OrchestratorConfigBinpackingDisruptionBudgetScheduleArgs'] schedule: Schedule for disruption budget
        """
        pulumi.set(__self__, "nodes", nodes)
        if reasons is not None:
            pulumi.set(__self__, "reasons", reasons)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)

    @_builtins.property
    @pulumi.getter
    def nodes(self) -> pulumi.Input[_builtins.str]:
        """
        Number or percentage of Nodes to consider for disruption
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "nodes", value)

    @_builtins.property
    @pulumi.getter
    def reasons(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Reasons for disruption
        """
        return pulumi.get(self, "reasons")

    @reasons.setter
    def reasons(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "reasons", value)

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['OrchestratorConfigBinpackingDisruptionBudgetScheduleArgs']]:
        """
        Schedule for disruption budget
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['OrchestratorConfigBinpackingDisruptionBudgetScheduleArgs']]):
        pulumi.set(self, "schedule", value)


if not MYPY:
    class OrchestratorConfigBinpackingDisruptionBudgetScheduleArgsDict(TypedDict):
        duration: pulumi.Input[_builtins.str]
        """
        Duration for disruption budget
        """
        frequency: pulumi.Input[_builtins.str]
        """
        Frequency for disruption budget
        """
elif False:
    OrchestratorConfigBinpackingDisruptionBudgetScheduleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OrchestratorConfigBinpackingDisruptionBudgetScheduleArgs:
    def __init__(__self__, *,
                 duration: pulumi.Input[_builtins.str],
                 frequency: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] duration: Duration for disruption budget
        :param pulumi.Input[_builtins.str] frequency: Frequency for disruption budget
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "frequency", frequency)

    @_builtins.property
    @pulumi.getter
    def duration(self) -> pulumi.Input[_builtins.str]:
        """
        Duration for disruption budget
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "duration", value)

    @_builtins.property
    @pulumi.getter
    def frequency(self) -> pulumi.Input[_builtins.str]:
        """
        Frequency for disruption budget
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "frequency", value)


if not MYPY:
    class OrchestratorConfigBinpackingPodEvictionArgsDict(TypedDict):
        threshold: pulumi.Input['OrchestratorConfigBinpackingPodEvictionThresholdArgsDict']
        """
        Minimum Threshold for considering a node as underutilized
        """
elif False:
    OrchestratorConfigBinpackingPodEvictionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OrchestratorConfigBinpackingPodEvictionArgs:
    def __init__(__self__, *,
                 threshold: pulumi.Input['OrchestratorConfigBinpackingPodEvictionThresholdArgs']):
        """
        :param pulumi.Input['OrchestratorConfigBinpackingPodEvictionThresholdArgs'] threshold: Minimum Threshold for considering a node as underutilized
        """
        pulumi.set(__self__, "threshold", threshold)

    @_builtins.property
    @pulumi.getter
    def threshold(self) -> pulumi.Input['OrchestratorConfigBinpackingPodEvictionThresholdArgs']:
        """
        Minimum Threshold for considering a node as underutilized
        """
        return pulumi.get(self, "threshold")

    @threshold.setter
    def threshold(self, value: pulumi.Input['OrchestratorConfigBinpackingPodEvictionThresholdArgs']):
        pulumi.set(self, "threshold", value)


if not MYPY:
    class OrchestratorConfigBinpackingPodEvictionThresholdArgsDict(TypedDict):
        cpu: pulumi.Input[_builtins.float]
        """
        CPU percentage for considering a node as underutilized
        """
        memory: pulumi.Input[_builtins.float]
        """
        Memory percentage for considering a node as underutilized
        """
elif False:
    OrchestratorConfigBinpackingPodEvictionThresholdArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OrchestratorConfigBinpackingPodEvictionThresholdArgs:
    def __init__(__self__, *,
                 cpu: pulumi.Input[_builtins.float],
                 memory: pulumi.Input[_builtins.float]):
        """
        :param pulumi.Input[_builtins.float] cpu: CPU percentage for considering a node as underutilized
        :param pulumi.Input[_builtins.float] memory: Memory percentage for considering a node as underutilized
        """
        pulumi.set(__self__, "cpu", cpu)
        pulumi.set(__self__, "memory", memory)

    @_builtins.property
    @pulumi.getter
    def cpu(self) -> pulumi.Input[_builtins.float]:
        """
        CPU percentage for considering a node as underutilized
        """
        return pulumi.get(self, "cpu")

    @cpu.setter
    def cpu(self, value: pulumi.Input[_builtins.float]):
        pulumi.set(self, "cpu", value)

    @_builtins.property
    @pulumi.getter
    def memory(self) -> pulumi.Input[_builtins.float]:
        """
        Memory percentage for considering a node as underutilized
        """
        return pulumi.get(self, "memory")

    @memory.setter
    def memory(self, value: pulumi.Input[_builtins.float]):
        pulumi.set(self, "memory", value)


if not MYPY:
    class OrchestratorConfigCommitmentIntegrationArgsDict(TypedDict):
        enabled: pulumi.Input[_builtins.bool]
        """
        Flag to enable Commitment Integration
        """
        master_account_id: pulumi.Input[_builtins.str]
        """
        Master AWS account id for commitment integration
        """
elif False:
    OrchestratorConfigCommitmentIntegrationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OrchestratorConfigCommitmentIntegrationArgs:
    def __init__(__self__, *,
                 enabled: pulumi.Input[_builtins.bool],
                 master_account_id: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.bool] enabled: Flag to enable Commitment Integration
        :param pulumi.Input[_builtins.str] master_account_id: Master AWS account id for commitment integration
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "master_account_id", master_account_id)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[_builtins.bool]:
        """
        Flag to enable Commitment Integration
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="masterAccountId")
    def master_account_id(self) -> pulumi.Input[_builtins.str]:
        """
        Master AWS account id for commitment integration
        """
        return pulumi.get(self, "master_account_id")

    @master_account_id.setter
    def master_account_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "master_account_id", value)


if not MYPY:
    class OrchestratorConfigDistributionArgsDict(TypedDict):
        ondemand_replica_percentage: pulumi.Input[_builtins.float]
        """
        Percentage of on-demand replicas required for workloads
        """
        base_ondemand_capacity: NotRequired[pulumi.Input[_builtins.int]]
        """
        Number of minimum ondemand replicas required for workloads
        """
        selector: NotRequired[pulumi.Input[_builtins.str]]
        """
        Selector for choosing workloads for distribution
        """
        strategy: NotRequired[pulumi.Input[_builtins.str]]
        """
        Strategy for choosing spot nodes for cluster
        """
elif False:
    OrchestratorConfigDistributionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OrchestratorConfigDistributionArgs:
    def __init__(__self__, *,
                 ondemand_replica_percentage: pulumi.Input[_builtins.float],
                 base_ondemand_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 selector: Optional[pulumi.Input[_builtins.str]] = None,
                 strategy: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.float] ondemand_replica_percentage: Percentage of on-demand replicas required for workloads
        :param pulumi.Input[_builtins.int] base_ondemand_capacity: Number of minimum ondemand replicas required for workloads
        :param pulumi.Input[_builtins.str] selector: Selector for choosing workloads for distribution
        :param pulumi.Input[_builtins.str] strategy: Strategy for choosing spot nodes for cluster
        """
        pulumi.set(__self__, "ondemand_replica_percentage", ondemand_replica_percentage)
        if base_ondemand_capacity is not None:
            pulumi.set(__self__, "base_ondemand_capacity", base_ondemand_capacity)
        if selector is not None:
            pulumi.set(__self__, "selector", selector)
        if strategy is not None:
            pulumi.set(__self__, "strategy", strategy)

    @_builtins.property
    @pulumi.getter(name="ondemandReplicaPercentage")
    def ondemand_replica_percentage(self) -> pulumi.Input[_builtins.float]:
        """
        Percentage of on-demand replicas required for workloads
        """
        return pulumi.get(self, "ondemand_replica_percentage")

    @ondemand_replica_percentage.setter
    def ondemand_replica_percentage(self, value: pulumi.Input[_builtins.float]):
        pulumi.set(self, "ondemand_replica_percentage", value)

    @_builtins.property
    @pulumi.getter(name="baseOndemandCapacity")
    def base_ondemand_capacity(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of minimum ondemand replicas required for workloads
        """
        return pulumi.get(self, "base_ondemand_capacity")

    @base_ondemand_capacity.setter
    def base_ondemand_capacity(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "base_ondemand_capacity", value)

    @_builtins.property
    @pulumi.getter
    def selector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Selector for choosing workloads for distribution
        """
        return pulumi.get(self, "selector")

    @selector.setter
    def selector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "selector", value)

    @_builtins.property
    @pulumi.getter
    def strategy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Strategy for choosing spot nodes for cluster
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "strategy", value)


if not MYPY:
    class OrchestratorConfigNodePreferencesArgsDict(TypedDict):
        reverse_fallback_interval: NotRequired[pulumi.Input[_builtins.str]]
        """
        Reverse fallback interval
        """
        ttl: NotRequired[pulumi.Input[_builtins.str]]
        """
        TTL for nodes
        """
elif False:
    OrchestratorConfigNodePreferencesArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OrchestratorConfigNodePreferencesArgs:
    def __init__(__self__, *,
                 reverse_fallback_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 ttl: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] reverse_fallback_interval: Reverse fallback interval
        :param pulumi.Input[_builtins.str] ttl: TTL for nodes
        """
        if reverse_fallback_interval is not None:
            pulumi.set(__self__, "reverse_fallback_interval", reverse_fallback_interval)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)

    @_builtins.property
    @pulumi.getter(name="reverseFallbackInterval")
    def reverse_fallback_interval(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Reverse fallback interval
        """
        return pulumi.get(self, "reverse_fallback_interval")

    @reverse_fallback_interval.setter
    def reverse_fallback_interval(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reverse_fallback_interval", value)

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        TTL for nodes
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ttl", value)


if not MYPY:
    class OrchestratorConfigReplacementScheduleArgsDict(TypedDict):
        applies_to: pulumi.Input['OrchestratorConfigReplacementScheduleAppliesToArgsDict']
        """
        Defines the scope of the replacement schedule
        """
        window_type: pulumi.Input[_builtins.str]
        """
        Window type for replacement schedule
        """
        window_details: NotRequired[pulumi.Input['OrchestratorConfigReplacementScheduleWindowDetailsArgsDict']]
elif False:
    OrchestratorConfigReplacementScheduleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OrchestratorConfigReplacementScheduleArgs:
    def __init__(__self__, *,
                 applies_to: pulumi.Input['OrchestratorConfigReplacementScheduleAppliesToArgs'],
                 window_type: pulumi.Input[_builtins.str],
                 window_details: Optional[pulumi.Input['OrchestratorConfigReplacementScheduleWindowDetailsArgs']] = None):
        """
        :param pulumi.Input['OrchestratorConfigReplacementScheduleAppliesToArgs'] applies_to: Defines the scope of the replacement schedule
        :param pulumi.Input[_builtins.str] window_type: Window type for replacement schedule
        """
        pulumi.set(__self__, "applies_to", applies_to)
        pulumi.set(__self__, "window_type", window_type)
        if window_details is not None:
            pulumi.set(__self__, "window_details", window_details)

    @_builtins.property
    @pulumi.getter(name="appliesTo")
    def applies_to(self) -> pulumi.Input['OrchestratorConfigReplacementScheduleAppliesToArgs']:
        """
        Defines the scope of the replacement schedule
        """
        return pulumi.get(self, "applies_to")

    @applies_to.setter
    def applies_to(self, value: pulumi.Input['OrchestratorConfigReplacementScheduleAppliesToArgs']):
        pulumi.set(self, "applies_to", value)

    @_builtins.property
    @pulumi.getter(name="windowType")
    def window_type(self) -> pulumi.Input[_builtins.str]:
        """
        Window type for replacement schedule
        """
        return pulumi.get(self, "window_type")

    @window_type.setter
    def window_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "window_type", value)

    @_builtins.property
    @pulumi.getter(name="windowDetails")
    def window_details(self) -> Optional[pulumi.Input['OrchestratorConfigReplacementScheduleWindowDetailsArgs']]:
        return pulumi.get(self, "window_details")

    @window_details.setter
    def window_details(self, value: Optional[pulumi.Input['OrchestratorConfigReplacementScheduleWindowDetailsArgs']]):
        pulumi.set(self, "window_details", value)


if not MYPY:
    class OrchestratorConfigReplacementScheduleAppliesToArgsDict(TypedDict):
        consolidation: pulumi.Input[_builtins.bool]
        harness_pod_eviction: pulumi.Input[_builtins.bool]
        reverse_fallback: pulumi.Input[_builtins.bool]
elif False:
    OrchestratorConfigReplacementScheduleAppliesToArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OrchestratorConfigReplacementScheduleAppliesToArgs:
    def __init__(__self__, *,
                 consolidation: pulumi.Input[_builtins.bool],
                 harness_pod_eviction: pulumi.Input[_builtins.bool],
                 reverse_fallback: pulumi.Input[_builtins.bool]):
        pulumi.set(__self__, "consolidation", consolidation)
        pulumi.set(__self__, "harness_pod_eviction", harness_pod_eviction)
        pulumi.set(__self__, "reverse_fallback", reverse_fallback)

    @_builtins.property
    @pulumi.getter
    def consolidation(self) -> pulumi.Input[_builtins.bool]:
        return pulumi.get(self, "consolidation")

    @consolidation.setter
    def consolidation(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "consolidation", value)

    @_builtins.property
    @pulumi.getter(name="harnessPodEviction")
    def harness_pod_eviction(self) -> pulumi.Input[_builtins.bool]:
        return pulumi.get(self, "harness_pod_eviction")

    @harness_pod_eviction.setter
    def harness_pod_eviction(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "harness_pod_eviction", value)

    @_builtins.property
    @pulumi.getter(name="reverseFallback")
    def reverse_fallback(self) -> pulumi.Input[_builtins.bool]:
        return pulumi.get(self, "reverse_fallback")

    @reverse_fallback.setter
    def reverse_fallback(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "reverse_fallback", value)


if not MYPY:
    class OrchestratorConfigReplacementScheduleWindowDetailsArgsDict(TypedDict):
        days: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]
        """
        List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        """
        time_zone: pulumi.Input[_builtins.str]
        """
        Time zone in which the schedule needs to be executed. Example Valid values: UTC, America/New*York, Europe/London, Asia/Kolkata, Asia/Tokyo, Asia/Hong*Kong, Asia/Singapore, Australia/Melbourne and Australia/Sydney.
        """
        all_day: NotRequired[pulumi.Input[_builtins.bool]]
        end_time: NotRequired[pulumi.Input[_builtins.str]]
        """
        End time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        start_time: NotRequired[pulumi.Input[_builtins.str]]
        """
        Start time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
elif False:
    OrchestratorConfigReplacementScheduleWindowDetailsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OrchestratorConfigReplacementScheduleWindowDetailsArgs:
    def __init__(__self__, *,
                 days: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 time_zone: pulumi.Input[_builtins.str],
                 all_day: Optional[pulumi.Input[_builtins.bool]] = None,
                 end_time: Optional[pulumi.Input[_builtins.str]] = None,
                 start_time: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] days: List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        :param pulumi.Input[_builtins.str] time_zone: Time zone in which the schedule needs to be executed. Example Valid values: UTC, America/New*York, Europe/London, Asia/Kolkata, Asia/Tokyo, Asia/Hong*Kong, Asia/Singapore, Australia/Melbourne and Australia/Sydney.
        :param pulumi.Input[_builtins.str] end_time: End time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        :param pulumi.Input[_builtins.str] start_time: Start time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        pulumi.set(__self__, "days", days)
        pulumi.set(__self__, "time_zone", time_zone)
        if all_day is not None:
            pulumi.set(__self__, "all_day", all_day)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)

    @_builtins.property
    @pulumi.getter
    def days(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        """
        return pulumi.get(self, "days")

    @days.setter
    def days(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "days", value)

    @_builtins.property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> pulumi.Input[_builtins.str]:
        """
        Time zone in which the schedule needs to be executed. Example Valid values: UTC, America/New*York, Europe/London, Asia/Kolkata, Asia/Tokyo, Asia/Hong*Kong, Asia/Singapore, Australia/Melbourne and Australia/Sydney.
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "time_zone", value)

    @_builtins.property
    @pulumi.getter(name="allDay")
    def all_day(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "all_day")

    @all_day.setter
    def all_day(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "all_day", value)

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        End time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "end_time", value)

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Start time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "start_time", value)


if not MYPY:
    class GetOrchestratorConfigBinpackingArgsDict(TypedDict):
        disruption: NotRequired['GetOrchestratorConfigBinpackingDisruptionArgsDict']
        """
        Harness disruption configuration
        """
        pod_eviction: NotRequired['GetOrchestratorConfigBinpackingPodEvictionArgsDict']
        """
        Harness Pod Evictor Configuration
        """
elif False:
    GetOrchestratorConfigBinpackingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetOrchestratorConfigBinpackingArgs:
    def __init__(__self__, *,
                 disruption: Optional['GetOrchestratorConfigBinpackingDisruptionArgs'] = None,
                 pod_eviction: Optional['GetOrchestratorConfigBinpackingPodEvictionArgs'] = None):
        """
        :param 'GetOrchestratorConfigBinpackingDisruptionArgs' disruption: Harness disruption configuration
        :param 'GetOrchestratorConfigBinpackingPodEvictionArgs' pod_eviction: Harness Pod Evictor Configuration
        """
        if disruption is not None:
            pulumi.set(__self__, "disruption", disruption)
        if pod_eviction is not None:
            pulumi.set(__self__, "pod_eviction", pod_eviction)

    @_builtins.property
    @pulumi.getter
    def disruption(self) -> Optional['GetOrchestratorConfigBinpackingDisruptionArgs']:
        """
        Harness disruption configuration
        """
        return pulumi.get(self, "disruption")

    @disruption.setter
    def disruption(self, value: Optional['GetOrchestratorConfigBinpackingDisruptionArgs']):
        pulumi.set(self, "disruption", value)

    @_builtins.property
    @pulumi.getter(name="podEviction")
    def pod_eviction(self) -> Optional['GetOrchestratorConfigBinpackingPodEvictionArgs']:
        """
        Harness Pod Evictor Configuration
        """
        return pulumi.get(self, "pod_eviction")

    @pod_eviction.setter
    def pod_eviction(self, value: Optional['GetOrchestratorConfigBinpackingPodEvictionArgs']):
        pulumi.set(self, "pod_eviction", value)


if not MYPY:
    class GetOrchestratorConfigBinpackingDisruptionArgsDict(TypedDict):
        budgets: NotRequired[Sequence['GetOrchestratorConfigBinpackingDisruptionBudgetArgsDict']]
        """
        Budgets for disruption
        """
        criteria: NotRequired[_builtins.str]
        """
        Criteria for considering a nodes for disruption
        """
        delay: NotRequired[_builtins.str]
        """
        Deletion delay
        """
elif False:
    GetOrchestratorConfigBinpackingDisruptionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetOrchestratorConfigBinpackingDisruptionArgs:
    def __init__(__self__, *,
                 budgets: Optional[Sequence['GetOrchestratorConfigBinpackingDisruptionBudgetArgs']] = None,
                 criteria: Optional[_builtins.str] = None,
                 delay: Optional[_builtins.str] = None):
        """
        :param Sequence['GetOrchestratorConfigBinpackingDisruptionBudgetArgs'] budgets: Budgets for disruption
        :param _builtins.str criteria: Criteria for considering a nodes for disruption
        :param _builtins.str delay: Deletion delay
        """
        if budgets is not None:
            pulumi.set(__self__, "budgets", budgets)
        if criteria is not None:
            pulumi.set(__self__, "criteria", criteria)
        if delay is not None:
            pulumi.set(__self__, "delay", delay)

    @_builtins.property
    @pulumi.getter
    def budgets(self) -> Optional[Sequence['GetOrchestratorConfigBinpackingDisruptionBudgetArgs']]:
        """
        Budgets for disruption
        """
        return pulumi.get(self, "budgets")

    @budgets.setter
    def budgets(self, value: Optional[Sequence['GetOrchestratorConfigBinpackingDisruptionBudgetArgs']]):
        pulumi.set(self, "budgets", value)

    @_builtins.property
    @pulumi.getter
    def criteria(self) -> Optional[_builtins.str]:
        """
        Criteria for considering a nodes for disruption
        """
        return pulumi.get(self, "criteria")

    @criteria.setter
    def criteria(self, value: Optional[_builtins.str]):
        pulumi.set(self, "criteria", value)

    @_builtins.property
    @pulumi.getter
    def delay(self) -> Optional[_builtins.str]:
        """
        Deletion delay
        """
        return pulumi.get(self, "delay")

    @delay.setter
    def delay(self, value: Optional[_builtins.str]):
        pulumi.set(self, "delay", value)


if not MYPY:
    class GetOrchestratorConfigBinpackingDisruptionBudgetArgsDict(TypedDict):
        nodes: _builtins.str
        """
        Number or percentage of Nodes to consider for disruption
        """
        reasons: NotRequired[Sequence[_builtins.str]]
        """
        Reasons for disruption
        """
        schedule: NotRequired['GetOrchestratorConfigBinpackingDisruptionBudgetScheduleArgsDict']
        """
        Schedule for disruption budget
        """
elif False:
    GetOrchestratorConfigBinpackingDisruptionBudgetArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetOrchestratorConfigBinpackingDisruptionBudgetArgs:
    def __init__(__self__, *,
                 nodes: _builtins.str,
                 reasons: Optional[Sequence[_builtins.str]] = None,
                 schedule: Optional['GetOrchestratorConfigBinpackingDisruptionBudgetScheduleArgs'] = None):
        """
        :param _builtins.str nodes: Number or percentage of Nodes to consider for disruption
        :param Sequence[_builtins.str] reasons: Reasons for disruption
        :param 'GetOrchestratorConfigBinpackingDisruptionBudgetScheduleArgs' schedule: Schedule for disruption budget
        """
        pulumi.set(__self__, "nodes", nodes)
        if reasons is not None:
            pulumi.set(__self__, "reasons", reasons)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)

    @_builtins.property
    @pulumi.getter
    def nodes(self) -> _builtins.str:
        """
        Number or percentage of Nodes to consider for disruption
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: _builtins.str):
        pulumi.set(self, "nodes", value)

    @_builtins.property
    @pulumi.getter
    def reasons(self) -> Optional[Sequence[_builtins.str]]:
        """
        Reasons for disruption
        """
        return pulumi.get(self, "reasons")

    @reasons.setter
    def reasons(self, value: Optional[Sequence[_builtins.str]]):
        pulumi.set(self, "reasons", value)

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional['GetOrchestratorConfigBinpackingDisruptionBudgetScheduleArgs']:
        """
        Schedule for disruption budget
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional['GetOrchestratorConfigBinpackingDisruptionBudgetScheduleArgs']):
        pulumi.set(self, "schedule", value)


if not MYPY:
    class GetOrchestratorConfigBinpackingDisruptionBudgetScheduleArgsDict(TypedDict):
        duration: _builtins.str
        """
        Duration for disruption budget
        """
        frequency: _builtins.str
        """
        Frequency for disruption budget
        """
elif False:
    GetOrchestratorConfigBinpackingDisruptionBudgetScheduleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetOrchestratorConfigBinpackingDisruptionBudgetScheduleArgs:
    def __init__(__self__, *,
                 duration: _builtins.str,
                 frequency: _builtins.str):
        """
        :param _builtins.str duration: Duration for disruption budget
        :param _builtins.str frequency: Frequency for disruption budget
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "frequency", frequency)

    @_builtins.property
    @pulumi.getter
    def duration(self) -> _builtins.str:
        """
        Duration for disruption budget
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: _builtins.str):
        pulumi.set(self, "duration", value)

    @_builtins.property
    @pulumi.getter
    def frequency(self) -> _builtins.str:
        """
        Frequency for disruption budget
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: _builtins.str):
        pulumi.set(self, "frequency", value)


if not MYPY:
    class GetOrchestratorConfigBinpackingPodEvictionArgsDict(TypedDict):
        threshold: 'GetOrchestratorConfigBinpackingPodEvictionThresholdArgsDict'
        """
        Minimum Threshold for considering a node as underutilized
        """
elif False:
    GetOrchestratorConfigBinpackingPodEvictionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetOrchestratorConfigBinpackingPodEvictionArgs:
    def __init__(__self__, *,
                 threshold: 'GetOrchestratorConfigBinpackingPodEvictionThresholdArgs'):
        """
        :param 'GetOrchestratorConfigBinpackingPodEvictionThresholdArgs' threshold: Minimum Threshold for considering a node as underutilized
        """
        pulumi.set(__self__, "threshold", threshold)

    @_builtins.property
    @pulumi.getter
    def threshold(self) -> 'GetOrchestratorConfigBinpackingPodEvictionThresholdArgs':
        """
        Minimum Threshold for considering a node as underutilized
        """
        return pulumi.get(self, "threshold")

    @threshold.setter
    def threshold(self, value: 'GetOrchestratorConfigBinpackingPodEvictionThresholdArgs'):
        pulumi.set(self, "threshold", value)


if not MYPY:
    class GetOrchestratorConfigBinpackingPodEvictionThresholdArgsDict(TypedDict):
        cpu: _builtins.float
        """
        CPU percentage for considering a node as underutilized
        """
        memory: _builtins.float
        """
        Memory percentage for considering a node as underutilized
        """
elif False:
    GetOrchestratorConfigBinpackingPodEvictionThresholdArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetOrchestratorConfigBinpackingPodEvictionThresholdArgs:
    def __init__(__self__, *,
                 cpu: _builtins.float,
                 memory: _builtins.float):
        """
        :param _builtins.float cpu: CPU percentage for considering a node as underutilized
        :param _builtins.float memory: Memory percentage for considering a node as underutilized
        """
        pulumi.set(__self__, "cpu", cpu)
        pulumi.set(__self__, "memory", memory)

    @_builtins.property
    @pulumi.getter
    def cpu(self) -> _builtins.float:
        """
        CPU percentage for considering a node as underutilized
        """
        return pulumi.get(self, "cpu")

    @cpu.setter
    def cpu(self, value: _builtins.float):
        pulumi.set(self, "cpu", value)

    @_builtins.property
    @pulumi.getter
    def memory(self) -> _builtins.float:
        """
        Memory percentage for considering a node as underutilized
        """
        return pulumi.get(self, "memory")

    @memory.setter
    def memory(self, value: _builtins.float):
        pulumi.set(self, "memory", value)


if not MYPY:
    class GetOrchestratorConfigCommitmentIntegrationArgsDict(TypedDict):
        enabled: _builtins.bool
        """
        Flag to enable Commitment Integration
        """
        master_account_id: _builtins.str
        """
        Master AWS account id for commitment integration
        """
elif False:
    GetOrchestratorConfigCommitmentIntegrationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetOrchestratorConfigCommitmentIntegrationArgs:
    def __init__(__self__, *,
                 enabled: _builtins.bool,
                 master_account_id: _builtins.str):
        """
        :param _builtins.bool enabled: Flag to enable Commitment Integration
        :param _builtins.str master_account_id: Master AWS account id for commitment integration
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "master_account_id", master_account_id)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> _builtins.bool:
        """
        Flag to enable Commitment Integration
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: _builtins.bool):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="masterAccountId")
    def master_account_id(self) -> _builtins.str:
        """
        Master AWS account id for commitment integration
        """
        return pulumi.get(self, "master_account_id")

    @master_account_id.setter
    def master_account_id(self, value: _builtins.str):
        pulumi.set(self, "master_account_id", value)


if not MYPY:
    class GetOrchestratorConfigDistributionArgsDict(TypedDict):
        ondemand_replica_percentage: _builtins.float
        """
        Percentage of on-demand replicas required for workloads
        """
        base_ondemand_capacity: NotRequired[_builtins.int]
        """
        Number of minimum ondemand replicas required for workloads
        """
        selector: NotRequired[_builtins.str]
        """
        Selector for choosing workloads for distribution
        """
        strategy: NotRequired[_builtins.str]
        """
        Strategy for choosing spot nodes for cluster
        """
elif False:
    GetOrchestratorConfigDistributionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetOrchestratorConfigDistributionArgs:
    def __init__(__self__, *,
                 ondemand_replica_percentage: _builtins.float,
                 base_ondemand_capacity: Optional[_builtins.int] = None,
                 selector: Optional[_builtins.str] = None,
                 strategy: Optional[_builtins.str] = None):
        """
        :param _builtins.float ondemand_replica_percentage: Percentage of on-demand replicas required for workloads
        :param _builtins.int base_ondemand_capacity: Number of minimum ondemand replicas required for workloads
        :param _builtins.str selector: Selector for choosing workloads for distribution
        :param _builtins.str strategy: Strategy for choosing spot nodes for cluster
        """
        pulumi.set(__self__, "ondemand_replica_percentage", ondemand_replica_percentage)
        if base_ondemand_capacity is not None:
            pulumi.set(__self__, "base_ondemand_capacity", base_ondemand_capacity)
        if selector is not None:
            pulumi.set(__self__, "selector", selector)
        if strategy is not None:
            pulumi.set(__self__, "strategy", strategy)

    @_builtins.property
    @pulumi.getter(name="ondemandReplicaPercentage")
    def ondemand_replica_percentage(self) -> _builtins.float:
        """
        Percentage of on-demand replicas required for workloads
        """
        return pulumi.get(self, "ondemand_replica_percentage")

    @ondemand_replica_percentage.setter
    def ondemand_replica_percentage(self, value: _builtins.float):
        pulumi.set(self, "ondemand_replica_percentage", value)

    @_builtins.property
    @pulumi.getter(name="baseOndemandCapacity")
    def base_ondemand_capacity(self) -> Optional[_builtins.int]:
        """
        Number of minimum ondemand replicas required for workloads
        """
        return pulumi.get(self, "base_ondemand_capacity")

    @base_ondemand_capacity.setter
    def base_ondemand_capacity(self, value: Optional[_builtins.int]):
        pulumi.set(self, "base_ondemand_capacity", value)

    @_builtins.property
    @pulumi.getter
    def selector(self) -> Optional[_builtins.str]:
        """
        Selector for choosing workloads for distribution
        """
        return pulumi.get(self, "selector")

    @selector.setter
    def selector(self, value: Optional[_builtins.str]):
        pulumi.set(self, "selector", value)

    @_builtins.property
    @pulumi.getter
    def strategy(self) -> Optional[_builtins.str]:
        """
        Strategy for choosing spot nodes for cluster
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: Optional[_builtins.str]):
        pulumi.set(self, "strategy", value)


if not MYPY:
    class GetOrchestratorConfigNodePreferencesArgsDict(TypedDict):
        reverse_fallback_interval: NotRequired[_builtins.str]
        """
        Reverse fallback interval
        """
        ttl: NotRequired[_builtins.str]
        """
        TTL for nodes
        """
elif False:
    GetOrchestratorConfigNodePreferencesArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetOrchestratorConfigNodePreferencesArgs:
    def __init__(__self__, *,
                 reverse_fallback_interval: Optional[_builtins.str] = None,
                 ttl: Optional[_builtins.str] = None):
        """
        :param _builtins.str reverse_fallback_interval: Reverse fallback interval
        :param _builtins.str ttl: TTL for nodes
        """
        if reverse_fallback_interval is not None:
            pulumi.set(__self__, "reverse_fallback_interval", reverse_fallback_interval)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)

    @_builtins.property
    @pulumi.getter(name="reverseFallbackInterval")
    def reverse_fallback_interval(self) -> Optional[_builtins.str]:
        """
        Reverse fallback interval
        """
        return pulumi.get(self, "reverse_fallback_interval")

    @reverse_fallback_interval.setter
    def reverse_fallback_interval(self, value: Optional[_builtins.str]):
        pulumi.set(self, "reverse_fallback_interval", value)

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> Optional[_builtins.str]:
        """
        TTL for nodes
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[_builtins.str]):
        pulumi.set(self, "ttl", value)


if not MYPY:
    class GetOrchestratorConfigReplacementScheduleArgsDict(TypedDict):
        applies_to: 'GetOrchestratorConfigReplacementScheduleAppliesToArgsDict'
        """
        Defines the scope of the replacement schedule
        """
        window_type: _builtins.str
        """
        Window type for replacement schedule
        """
        window_details: NotRequired['GetOrchestratorConfigReplacementScheduleWindowDetailsArgsDict']
elif False:
    GetOrchestratorConfigReplacementScheduleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetOrchestratorConfigReplacementScheduleArgs:
    def __init__(__self__, *,
                 applies_to: 'GetOrchestratorConfigReplacementScheduleAppliesToArgs',
                 window_type: _builtins.str,
                 window_details: Optional['GetOrchestratorConfigReplacementScheduleWindowDetailsArgs'] = None):
        """
        :param 'GetOrchestratorConfigReplacementScheduleAppliesToArgs' applies_to: Defines the scope of the replacement schedule
        :param _builtins.str window_type: Window type for replacement schedule
        """
        pulumi.set(__self__, "applies_to", applies_to)
        pulumi.set(__self__, "window_type", window_type)
        if window_details is not None:
            pulumi.set(__self__, "window_details", window_details)

    @_builtins.property
    @pulumi.getter(name="appliesTo")
    def applies_to(self) -> 'GetOrchestratorConfigReplacementScheduleAppliesToArgs':
        """
        Defines the scope of the replacement schedule
        """
        return pulumi.get(self, "applies_to")

    @applies_to.setter
    def applies_to(self, value: 'GetOrchestratorConfigReplacementScheduleAppliesToArgs'):
        pulumi.set(self, "applies_to", value)

    @_builtins.property
    @pulumi.getter(name="windowType")
    def window_type(self) -> _builtins.str:
        """
        Window type for replacement schedule
        """
        return pulumi.get(self, "window_type")

    @window_type.setter
    def window_type(self, value: _builtins.str):
        pulumi.set(self, "window_type", value)

    @_builtins.property
    @pulumi.getter(name="windowDetails")
    def window_details(self) -> Optional['GetOrchestratorConfigReplacementScheduleWindowDetailsArgs']:
        return pulumi.get(self, "window_details")

    @window_details.setter
    def window_details(self, value: Optional['GetOrchestratorConfigReplacementScheduleWindowDetailsArgs']):
        pulumi.set(self, "window_details", value)


if not MYPY:
    class GetOrchestratorConfigReplacementScheduleAppliesToArgsDict(TypedDict):
        consolidation: _builtins.bool
        harness_pod_eviction: _builtins.bool
        reverse_fallback: _builtins.bool
elif False:
    GetOrchestratorConfigReplacementScheduleAppliesToArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetOrchestratorConfigReplacementScheduleAppliesToArgs:
    def __init__(__self__, *,
                 consolidation: _builtins.bool,
                 harness_pod_eviction: _builtins.bool,
                 reverse_fallback: _builtins.bool):
        pulumi.set(__self__, "consolidation", consolidation)
        pulumi.set(__self__, "harness_pod_eviction", harness_pod_eviction)
        pulumi.set(__self__, "reverse_fallback", reverse_fallback)

    @_builtins.property
    @pulumi.getter
    def consolidation(self) -> _builtins.bool:
        return pulumi.get(self, "consolidation")

    @consolidation.setter
    def consolidation(self, value: _builtins.bool):
        pulumi.set(self, "consolidation", value)

    @_builtins.property
    @pulumi.getter(name="harnessPodEviction")
    def harness_pod_eviction(self) -> _builtins.bool:
        return pulumi.get(self, "harness_pod_eviction")

    @harness_pod_eviction.setter
    def harness_pod_eviction(self, value: _builtins.bool):
        pulumi.set(self, "harness_pod_eviction", value)

    @_builtins.property
    @pulumi.getter(name="reverseFallback")
    def reverse_fallback(self) -> _builtins.bool:
        return pulumi.get(self, "reverse_fallback")

    @reverse_fallback.setter
    def reverse_fallback(self, value: _builtins.bool):
        pulumi.set(self, "reverse_fallback", value)


if not MYPY:
    class GetOrchestratorConfigReplacementScheduleWindowDetailsArgsDict(TypedDict):
        days: Sequence[_builtins.str]
        """
        List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        """
        time_zone: _builtins.str
        """
        Time zone in which the schedule needs to be executed. Example Valid values: UTC, America/New*York, Europe/London, Asia/Kolkata, Asia/Tokyo, Asia/Hong*Kong, Asia/Singapore, Australia/Melbourne and Australia/Sydney.
        """
        all_day: NotRequired[_builtins.bool]
        end_time: NotRequired[_builtins.str]
        """
        End time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        start_time: NotRequired[_builtins.str]
        """
        Start time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
elif False:
    GetOrchestratorConfigReplacementScheduleWindowDetailsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetOrchestratorConfigReplacementScheduleWindowDetailsArgs:
    def __init__(__self__, *,
                 days: Sequence[_builtins.str],
                 time_zone: _builtins.str,
                 all_day: Optional[_builtins.bool] = None,
                 end_time: Optional[_builtins.str] = None,
                 start_time: Optional[_builtins.str] = None):
        """
        :param Sequence[_builtins.str] days: List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        :param _builtins.str time_zone: Time zone in which the schedule needs to be executed. Example Valid values: UTC, America/New*York, Europe/London, Asia/Kolkata, Asia/Tokyo, Asia/Hong*Kong, Asia/Singapore, Australia/Melbourne and Australia/Sydney.
        :param _builtins.str end_time: End time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        :param _builtins.str start_time: Start time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        pulumi.set(__self__, "days", days)
        pulumi.set(__self__, "time_zone", time_zone)
        if all_day is not None:
            pulumi.set(__self__, "all_day", all_day)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)

    @_builtins.property
    @pulumi.getter
    def days(self) -> Sequence[_builtins.str]:
        """
        List of days on which schedule need to be active. Valid values are SUN, MON, TUE, WED, THU, FRI and SAT.
        """
        return pulumi.get(self, "days")

    @days.setter
    def days(self, value: Sequence[_builtins.str]):
        pulumi.set(self, "days", value)

    @_builtins.property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> _builtins.str:
        """
        Time zone in which the schedule needs to be executed. Example Valid values: UTC, America/New*York, Europe/London, Asia/Kolkata, Asia/Tokyo, Asia/Hong*Kong, Asia/Singapore, Australia/Melbourne and Australia/Sydney.
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: _builtins.str):
        pulumi.set(self, "time_zone", value)

    @_builtins.property
    @pulumi.getter(name="allDay")
    def all_day(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "all_day")

    @all_day.setter
    def all_day(self, value: Optional[_builtins.bool]):
        pulumi.set(self, "all_day", value)

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[_builtins.str]:
        """
        End time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[_builtins.str]):
        pulumi.set(self, "end_time", value)

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[_builtins.str]:
        """
        Start time of schedule in the format HH:MM. Eg : 13:15 for 01:15pm
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[_builtins.str]):
        pulumi.set(self, "start_time", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetWorkspaceResult',
    'AwaitableGetWorkspaceResult',
    'get_workspace',
    'get_workspace_output',
]

@pulumi.output_type
class GetWorkspaceResult:
    """
    A collection of values returned by getWorkspace.
    """
    def __init__(__self__, connectors=None, cost_estimation_enabled=None, default_pipelines=None, description=None, environment_variables=None, id=None, identifier=None, name=None, org_id=None, project_id=None, provider_connector=None, provisioner_type=None, provisioner_version=None, repository=None, repository_branch=None, repository_commit=None, repository_connector=None, repository_path=None, repository_sha=None, tags=None, terraform_variable_files=None, terraform_variables=None, variable_sets=None):
        if connectors and not isinstance(connectors, list):
            raise TypeError("Expected argument 'connectors' to be a list")
        pulumi.set(__self__, "connectors", connectors)
        if cost_estimation_enabled and not isinstance(cost_estimation_enabled, bool):
            raise TypeError("Expected argument 'cost_estimation_enabled' to be a bool")
        pulumi.set(__self__, "cost_estimation_enabled", cost_estimation_enabled)
        if default_pipelines and not isinstance(default_pipelines, dict):
            raise TypeError("Expected argument 'default_pipelines' to be a dict")
        pulumi.set(__self__, "default_pipelines", default_pipelines)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if environment_variables and not isinstance(environment_variables, list):
            raise TypeError("Expected argument 'environment_variables' to be a list")
        pulumi.set(__self__, "environment_variables", environment_variables)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if provider_connector and not isinstance(provider_connector, str):
            raise TypeError("Expected argument 'provider_connector' to be a str")
        pulumi.set(__self__, "provider_connector", provider_connector)
        if provisioner_type and not isinstance(provisioner_type, str):
            raise TypeError("Expected argument 'provisioner_type' to be a str")
        pulumi.set(__self__, "provisioner_type", provisioner_type)
        if provisioner_version and not isinstance(provisioner_version, str):
            raise TypeError("Expected argument 'provisioner_version' to be a str")
        pulumi.set(__self__, "provisioner_version", provisioner_version)
        if repository and not isinstance(repository, str):
            raise TypeError("Expected argument 'repository' to be a str")
        pulumi.set(__self__, "repository", repository)
        if repository_branch and not isinstance(repository_branch, str):
            raise TypeError("Expected argument 'repository_branch' to be a str")
        pulumi.set(__self__, "repository_branch", repository_branch)
        if repository_commit and not isinstance(repository_commit, str):
            raise TypeError("Expected argument 'repository_commit' to be a str")
        pulumi.set(__self__, "repository_commit", repository_commit)
        if repository_connector and not isinstance(repository_connector, str):
            raise TypeError("Expected argument 'repository_connector' to be a str")
        pulumi.set(__self__, "repository_connector", repository_connector)
        if repository_path and not isinstance(repository_path, str):
            raise TypeError("Expected argument 'repository_path' to be a str")
        pulumi.set(__self__, "repository_path", repository_path)
        if repository_sha and not isinstance(repository_sha, str):
            raise TypeError("Expected argument 'repository_sha' to be a str")
        pulumi.set(__self__, "repository_sha", repository_sha)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if terraform_variable_files and not isinstance(terraform_variable_files, list):
            raise TypeError("Expected argument 'terraform_variable_files' to be a list")
        pulumi.set(__self__, "terraform_variable_files", terraform_variable_files)
        if terraform_variables and not isinstance(terraform_variables, list):
            raise TypeError("Expected argument 'terraform_variables' to be a list")
        pulumi.set(__self__, "terraform_variables", terraform_variables)
        if variable_sets and not isinstance(variable_sets, list):
            raise TypeError("Expected argument 'variable_sets' to be a list")
        pulumi.set(__self__, "variable_sets", variable_sets)

    @_builtins.property
    @pulumi.getter
    def connectors(self) -> Optional[Sequence['outputs.GetWorkspaceConnectorResult']]:
        """
        Provider connectors configured on the Workspace. Only one connector of a type is supported
        """
        return pulumi.get(self, "connectors")

    @_builtins.property
    @pulumi.getter(name="costEstimationEnabled")
    def cost_estimation_enabled(self) -> _builtins.bool:
        """
        If enabled cost estimation operations will be performed in this workspace
        """
        return pulumi.get(self, "cost_estimation_enabled")

    @_builtins.property
    @pulumi.getter(name="defaultPipelines")
    def default_pipelines(self) -> Mapping[str, _builtins.str]:
        """
        Default pipelines associated with this workspace
        """
        return pulumi.get(self, "default_pipelines")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the Workspace
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Sequence['outputs.GetWorkspaceEnvironmentVariableResult']:
        """
        Environment variables configured on the workspace
        """
        return pulumi.get(self, "environment_variables")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the Workspace
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the Workspace
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        Organization Identifier
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        Project Identifier
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="providerConnector")
    def provider_connector(self) -> _builtins.str:
        """
        Provider Connector is the reference to the connector for the infrastructure provider
        """
        return pulumi.get(self, "provider_connector")

    @_builtins.property
    @pulumi.getter(name="provisionerType")
    def provisioner_type(self) -> _builtins.str:
        """
        Provisioner type defines the provisioning tool to use.
        """
        return pulumi.get(self, "provisioner_type")

    @_builtins.property
    @pulumi.getter(name="provisionerVersion")
    def provisioner_version(self) -> _builtins.str:
        """
        Provisioner Version defines the tool version to use
        """
        return pulumi.get(self, "provisioner_version")

    @_builtins.property
    @pulumi.getter
    def repository(self) -> _builtins.str:
        """
        Repository is the name of the repository to use
        """
        return pulumi.get(self, "repository")

    @_builtins.property
    @pulumi.getter(name="repositoryBranch")
    def repository_branch(self) -> _builtins.str:
        """
        Repository Branch in which the code should be accessed
        """
        return pulumi.get(self, "repository_branch")

    @_builtins.property
    @pulumi.getter(name="repositoryCommit")
    def repository_commit(self) -> _builtins.str:
        """
        Repository Tag in which the code should be accessed
        """
        return pulumi.get(self, "repository_commit")

    @_builtins.property
    @pulumi.getter(name="repositoryConnector")
    def repository_connector(self) -> _builtins.str:
        """
        Repository Connector is the reference to the connector to use for this code
        """
        return pulumi.get(self, "repository_connector")

    @_builtins.property
    @pulumi.getter(name="repositoryPath")
    def repository_path(self) -> _builtins.str:
        """
        Repository Path is the path in which the infra code resides
        """
        return pulumi.get(self, "repository_path")

    @_builtins.property
    @pulumi.getter(name="repositorySha")
    def repository_sha(self) -> _builtins.str:
        """
        Repository Commit SHA in which the code should be accessed
        """
        return pulumi.get(self, "repository_sha")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[_builtins.str]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="terraformVariableFiles")
    def terraform_variable_files(self) -> Sequence['outputs.GetWorkspaceTerraformVariableFileResult']:
        return pulumi.get(self, "terraform_variable_files")

    @_builtins.property
    @pulumi.getter(name="terraformVariables")
    def terraform_variables(self) -> Sequence['outputs.GetWorkspaceTerraformVariableResult']:
        return pulumi.get(self, "terraform_variables")

    @_builtins.property
    @pulumi.getter(name="variableSets")
    def variable_sets(self) -> Sequence[_builtins.str]:
        """
        Variable sets to use.
        """
        return pulumi.get(self, "variable_sets")


class AwaitableGetWorkspaceResult(GetWorkspaceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetWorkspaceResult(
            connectors=self.connectors,
            cost_estimation_enabled=self.cost_estimation_enabled,
            default_pipelines=self.default_pipelines,
            description=self.description,
            environment_variables=self.environment_variables,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            provider_connector=self.provider_connector,
            provisioner_type=self.provisioner_type,
            provisioner_version=self.provisioner_version,
            repository=self.repository,
            repository_branch=self.repository_branch,
            repository_commit=self.repository_commit,
            repository_connector=self.repository_connector,
            repository_path=self.repository_path,
            repository_sha=self.repository_sha,
            tags=self.tags,
            terraform_variable_files=self.terraform_variable_files,
            terraform_variables=self.terraform_variables,
            variable_sets=self.variable_sets)


def get_workspace(connectors: Optional[Sequence[Union['GetWorkspaceConnectorArgs', 'GetWorkspaceConnectorArgsDict']]] = None,
                  description: Optional[_builtins.str] = None,
                  environment_variables: Optional[Sequence[Union['GetWorkspaceEnvironmentVariableArgs', 'GetWorkspaceEnvironmentVariableArgsDict']]] = None,
                  identifier: Optional[_builtins.str] = None,
                  org_id: Optional[_builtins.str] = None,
                  project_id: Optional[_builtins.str] = None,
                  repository_branch: Optional[_builtins.str] = None,
                  repository_commit: Optional[_builtins.str] = None,
                  repository_sha: Optional[_builtins.str] = None,
                  tags: Optional[Sequence[_builtins.str]] = None,
                  terraform_variable_files: Optional[Sequence[Union['GetWorkspaceTerraformVariableFileArgs', 'GetWorkspaceTerraformVariableFileArgsDict']]] = None,
                  terraform_variables: Optional[Sequence[Union['GetWorkspaceTerraformVariableArgs', 'GetWorkspaceTerraformVariableArgsDict']]] = None,
                  variable_sets: Optional[Sequence[_builtins.str]] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetWorkspaceResult:
    """
    Data source for retrieving workspaces.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_workspace(identifier="identifier",
        org_id="org_id",
        project_id="project_id")
    ```


    :param Sequence[Union['GetWorkspaceConnectorArgs', 'GetWorkspaceConnectorArgsDict']] connectors: Provider connectors configured on the Workspace. Only one connector of a type is supported
    :param _builtins.str description: Description of the Workspace
    :param Sequence[Union['GetWorkspaceEnvironmentVariableArgs', 'GetWorkspaceEnvironmentVariableArgsDict']] environment_variables: Environment variables configured on the workspace
    :param _builtins.str identifier: Identifier of the Workspace
    :param _builtins.str org_id: Organization Identifier
    :param _builtins.str project_id: Project Identifier
    :param _builtins.str repository_branch: Repository Branch in which the code should be accessed
    :param _builtins.str repository_commit: Repository Tag in which the code should be accessed
    :param _builtins.str repository_sha: Repository Commit SHA in which the code should be accessed
    :param Sequence[_builtins.str] tags: Tags to associate with the resource.
    :param Sequence[_builtins.str] variable_sets: Variable sets to use.
    """
    __args__ = dict()
    __args__['connectors'] = connectors
    __args__['description'] = description
    __args__['environmentVariables'] = environment_variables
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['repositoryBranch'] = repository_branch
    __args__['repositoryCommit'] = repository_commit
    __args__['repositorySha'] = repository_sha
    __args__['tags'] = tags
    __args__['terraformVariableFiles'] = terraform_variable_files
    __args__['terraformVariables'] = terraform_variables
    __args__['variableSets'] = variable_sets
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getWorkspace:getWorkspace', __args__, opts=opts, typ=GetWorkspaceResult).value

    return AwaitableGetWorkspaceResult(
        connectors=pulumi.get(__ret__, 'connectors'),
        cost_estimation_enabled=pulumi.get(__ret__, 'cost_estimation_enabled'),
        default_pipelines=pulumi.get(__ret__, 'default_pipelines'),
        description=pulumi.get(__ret__, 'description'),
        environment_variables=pulumi.get(__ret__, 'environment_variables'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        provider_connector=pulumi.get(__ret__, 'provider_connector'),
        provisioner_type=pulumi.get(__ret__, 'provisioner_type'),
        provisioner_version=pulumi.get(__ret__, 'provisioner_version'),
        repository=pulumi.get(__ret__, 'repository'),
        repository_branch=pulumi.get(__ret__, 'repository_branch'),
        repository_commit=pulumi.get(__ret__, 'repository_commit'),
        repository_connector=pulumi.get(__ret__, 'repository_connector'),
        repository_path=pulumi.get(__ret__, 'repository_path'),
        repository_sha=pulumi.get(__ret__, 'repository_sha'),
        tags=pulumi.get(__ret__, 'tags'),
        terraform_variable_files=pulumi.get(__ret__, 'terraform_variable_files'),
        terraform_variables=pulumi.get(__ret__, 'terraform_variables'),
        variable_sets=pulumi.get(__ret__, 'variable_sets'))
def get_workspace_output(connectors: Optional[pulumi.Input[Optional[Sequence[Union['GetWorkspaceConnectorArgs', 'GetWorkspaceConnectorArgsDict']]]]] = None,
                         description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         environment_variables: Optional[pulumi.Input[Optional[Sequence[Union['GetWorkspaceEnvironmentVariableArgs', 'GetWorkspaceEnvironmentVariableArgsDict']]]]] = None,
                         identifier: Optional[pulumi.Input[_builtins.str]] = None,
                         org_id: Optional[pulumi.Input[_builtins.str]] = None,
                         project_id: Optional[pulumi.Input[_builtins.str]] = None,
                         repository_branch: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         repository_commit: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         repository_sha: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         tags: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                         terraform_variable_files: Optional[pulumi.Input[Optional[Sequence[Union['GetWorkspaceTerraformVariableFileArgs', 'GetWorkspaceTerraformVariableFileArgsDict']]]]] = None,
                         terraform_variables: Optional[pulumi.Input[Optional[Sequence[Union['GetWorkspaceTerraformVariableArgs', 'GetWorkspaceTerraformVariableArgsDict']]]]] = None,
                         variable_sets: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetWorkspaceResult]:
    """
    Data source for retrieving workspaces.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_workspace(identifier="identifier",
        org_id="org_id",
        project_id="project_id")
    ```


    :param Sequence[Union['GetWorkspaceConnectorArgs', 'GetWorkspaceConnectorArgsDict']] connectors: Provider connectors configured on the Workspace. Only one connector of a type is supported
    :param _builtins.str description: Description of the Workspace
    :param Sequence[Union['GetWorkspaceEnvironmentVariableArgs', 'GetWorkspaceEnvironmentVariableArgsDict']] environment_variables: Environment variables configured on the workspace
    :param _builtins.str identifier: Identifier of the Workspace
    :param _builtins.str org_id: Organization Identifier
    :param _builtins.str project_id: Project Identifier
    :param _builtins.str repository_branch: Repository Branch in which the code should be accessed
    :param _builtins.str repository_commit: Repository Tag in which the code should be accessed
    :param _builtins.str repository_sha: Repository Commit SHA in which the code should be accessed
    :param Sequence[_builtins.str] tags: Tags to associate with the resource.
    :param Sequence[_builtins.str] variable_sets: Variable sets to use.
    """
    __args__ = dict()
    __args__['connectors'] = connectors
    __args__['description'] = description
    __args__['environmentVariables'] = environment_variables
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['repositoryBranch'] = repository_branch
    __args__['repositoryCommit'] = repository_commit
    __args__['repositorySha'] = repository_sha
    __args__['tags'] = tags
    __args__['terraformVariableFiles'] = terraform_variable_files
    __args__['terraformVariables'] = terraform_variables
    __args__['variableSets'] = variable_sets
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getWorkspace:getWorkspace', __args__, opts=opts, typ=GetWorkspaceResult)
    return __ret__.apply(lambda __response__: GetWorkspaceResult(
        connectors=pulumi.get(__response__, 'connectors'),
        cost_estimation_enabled=pulumi.get(__response__, 'cost_estimation_enabled'),
        default_pipelines=pulumi.get(__response__, 'default_pipelines'),
        description=pulumi.get(__response__, 'description'),
        environment_variables=pulumi.get(__response__, 'environment_variables'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        provider_connector=pulumi.get(__response__, 'provider_connector'),
        provisioner_type=pulumi.get(__response__, 'provisioner_type'),
        provisioner_version=pulumi.get(__response__, 'provisioner_version'),
        repository=pulumi.get(__response__, 'repository'),
        repository_branch=pulumi.get(__response__, 'repository_branch'),
        repository_commit=pulumi.get(__response__, 'repository_commit'),
        repository_connector=pulumi.get(__response__, 'repository_connector'),
        repository_path=pulumi.get(__response__, 'repository_path'),
        repository_sha=pulumi.get(__response__, 'repository_sha'),
        tags=pulumi.get(__response__, 'tags'),
        terraform_variable_files=pulumi.get(__response__, 'terraform_variable_files'),
        terraform_variables=pulumi.get(__response__, 'terraform_variables'),
        variable_sets=pulumi.get(__response__, 'variable_sets')))
